==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>انقر على الأيقونة بالأسفل
أو اضغط على الاختصار مرة أخرى لإيقاف التسجيل</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>إلتقاط الشاشة</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>فشلت عملية الحفظ، نرجوا إجراء الحفظ في المجلد الرئيسي</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>انتهى التقاط الشاشة</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>اختر منطقة</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>تم حفظ 1%</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>إلتقاط صورة الشاشة سيبدأ خلال 1 ثانية</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>التراجع عن آخر إجراء</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>إلتقاط صورة الشاشة</translation>
    </message>
    <message>
        <source>View</source>
        <translation>معاينة</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>انتهت عملية التسجيل</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>تم حفظ 1%</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>إلتقاط صورة الشاشة سيبدأ خلال 1 ثانية </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>ادخل النص هنا</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>ابدء/لقطة شاشة</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>خروج/حفظ</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>رسم</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>تعديل الحجم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>اعدادات</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>بداية سريعة</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>تأخير لقطة الشاشة</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>لقطة شاشة كاملة</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>نسخ إلى الحافظة</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>شكل بيضاوي</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>تراجع</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>زيادة الارتفاع</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>زيادة الانخفاض</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>زيادة العرض يساراً</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>زيادة العرض يميناً</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>تقليل الارتفاع</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>تقليل الانخفاض</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>تقليل العرض يساراً</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>تقليل العرض يميناً</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>اختصارات شاشة العرض</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>ضبابي</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>فسيفسائي</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>تشغيل الصوت</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>ميكروفون</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>نظام الصوت</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>اطفاء الصوت</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>إظهار ضغطة المفتاح</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>إخفاء ضغطة المفتاح</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>تشغيل كاميرا الويب</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>اطفاء كاميرا الويب</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>إظهار النقرات</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>إخفاء النقرات</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>خيارات</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>إطار في الثانية FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>شكل بيضاوي</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>سهم</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>حفظ إلى</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>صور</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>تسجيلات</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>انقر على الأيقونة بالأسفل
أو اضغط على الاختصار مرة أخرى لإيقاف التسجيل</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>إلتقاط الشاشة</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>فشلت عملية الحفظ، نرجوا إجراء الحفظ في المجلد الرئيسي</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>انتهى التقاط الشاشة</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>اختر منطقة</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>تم حفظ 1%</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>التراجع عن آخر إجراء</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>معاينة</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>انتهت عملية التسجيل</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>تم حفظ 1%</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>إلتقاط صورة الشاشة سيبدأ خلال 1 ثانية </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>ادخل النص هنا</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>ابدء/لقطة شاشة</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>خروج/حفظ</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>رسم</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>تعديل الحجم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>اعدادات</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>بداية سريعة</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>تأخير لقطة الشاشة</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>لقطة شاشة كاملة</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>شكل بيضاوي</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>تراجع</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>زيادة الارتفاع</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>زيادة الانخفاض</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>زيادة العرض يساراً</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>زيادة العرض يميناً</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>تقليل الارتفاع</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>تقليل الانخفاض</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>تقليل العرض يساراً</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>تقليل العرض يميناً</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>اختصارات شاشة العرض</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>ابدأ التسجيل</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>خيارات</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>ضبابي</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>فسيفسائي</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>تشغيل الصوت</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>ميكروفون</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>نظام الصوت</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>اطفاء الصوت</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>إظهار ضغطة المفتاح</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>إخفاء ضغطة المفتاح</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>تشغيل كاميرا الويب</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>اطفاء كاميرا الويب</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>إظهار النقرات</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>خيارات</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>إطار في الثانية FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>شكل بيضاوي</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>سهم</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>حفظ إلى</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>صور</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>تسجيلات</translation>
    </message>
</context>
</TS>
